@@ -80,11 +80,13 @@ class Urllib3HttpConnection(Connection):
         kw = {}
 
         # if providing an SSL context, raise error if any other SSL related flag is used
-        if ssl_context and (verify_certs or ca_certs or ssl_version):
+        if ssl_context and (ca_certs or ssl_version):
             raise ImproperlyConfigured("When using `ssl_context`, `use_ssl`, `verify_certs`, `ca_certs` and `ssl_version` are not permitted")
 
         # if ssl_context provided use SSL by default
         if use_ssl or ssl_context:
+            ca_certs = CA_CERTS if ca_certs is None else ca_certs
+
             if not ca_certs and not ssl_context and verify_certs:
                 # If no ca_certs and no sslcontext passed and asking to verify certs
                 # raise error
@@ -97,10 +99,9 @@ class Urllib3HttpConnection(Connection):
 
             if not ssl_context:
                 # if SSLContext hasn't been passed in, create one.
-                cafile = CA_CERTS if ca_certs is None else ca_certs
                 # need to skip if sslContext isn't avail
                 try:
-                    ssl_context = create_ssl_context(cafile=cafile)
+                    ssl_context = create_ssl_context(cafile=ca_certs)
                 except AttributeError:
                     ssl_context = None
 
@@ -141,10 +142,11 @@ class Urllib3HttpConnection(Connection):
             if not isinstance(method, str):
                 method = method.encode('utf-8')
 
+            request_headers = self.headers
             if headers:
-                request_headers = dict(self.headers)
-                request_headers.update(headers or {})
-            response = self.pool.urlopen(method, url, body, retries=False, headers=self.headers, **kw)
+                request_headers = request_headers.copy()
+                request_headers.update(headers)
+            response = self.pool.urlopen(method, url, body, retries=False, headers=request_headers, **kw)
             duration = time.time() - start
             raw_data = response.data.decode('utf-8')
         except Exception as e:
